@@ -5,10 +5,6 @@ class RedisError(Exception):
     pass
 
 
-class AuthenticationError(RedisError):
-    pass
-
-
 class ConnectionError(RedisError):
     pass
 
@@ -17,6 +13,10 @@ class TimeoutError(RedisError):
     pass
 
 
+class AuthenticationError(ConnectionError):
+    pass
+
+
 class BusyLoadingError(ConnectionError):
     pass
 
@@ -53,6 +53,10 @@ class ReadOnlyError(ResponseError):
     pass
 
 
+class NoPermissionError(ResponseError):
+    pass
+
+
 class LockError(RedisError, ValueError):
     "Errors acquiring or releasing a lock"
     # NOTE: For backwards compatability, this class derives from ValueError.
@@ -63,3 +67,16 @@ class LockError(RedisError, ValueError):
 class LockNotOwnedError(LockError):
     "Error trying to extend or release a lock that is (no longer) owned"
     pass
+
+
+class ChildDeadlockedError(Exception):
+    "Error indicating that a child process is deadlocked after a fork()"
+    pass
+
+
+class AuthenticationWrongNumberOfArgsError(ResponseError):
+    """
+    An error to indicate that the wrong number of args
+    were sent to the AUTH command
+    """
+    pass
